# 项目引入

## VUE 2

```js
import Vue from 'vue';   
import utracking from 'utracking';   

Vue.prototype.$tracking = utracking;
```

## VUE 3

```js
import { createApp } from 'vue'
import App from './App.vue' 
import utracking from 'utracking';

const app = createApp(App);
app.config.globalProperties.$tracking = utracking;
```

# 使用

## VUE 2

```js
this.$tracking.setApp ('my-app')
```

## VUE 3

```js
import { getCurrentInstance } from "vue";
const { proxy } = getCurrentInstance();
proxy.$tracking.setApp ('my-app')
```


# 标记类函数与方法
建议在App启动式进行标记，作为初始化记录和

## SetApp
请为每个App设定唯一的id，用以后台数据检索

```js
this.$tracking.setApp (app_id)
```


## SetProperty
可为App记录任意属性，属性值仅可为字符串或数字。    
在单个生命周期中，对同一属性值的修改，会存在时间顺序上的覆盖。如果希望获得某一属性的变化记录，可使用log方法。

```js
this.$tracking.setProperty (property, value)
```
- **property** 必填    
- value 选填，默认值为空

# 跟踪类函数与方法
方法中主要使用的是参数如下
- 交互触发的系统鼠标事件 **e**
- 自定义事件名称 **event_name**，可以是任意名称，方便后续数据分析时识别节点
- 事件类型 **type**，对事件进行分类，默认的系统事件类型有click、blur、nav



## Click
记录点击事件

```js
this.$tracking.click(e, event_name)
```

- **e** 必填    
- event_name 选填，默认值为空


## Blur
记录失去焦点，主要用于输入框

```js
this.$tracking.blur(e, event_name)
```

- **e** 必填    
- event_name 选填，默认值为空


## Nav
跟踪页面跳转

```js
this.$tracking.nav(to, e, event_name)
```

- **to** 必填，跳转的目标路径    
- e 选填，默认值为空   
- event_name 选填，默认值为空


## Log
自定义事件类型跟踪

```js
this.$tracking.log(type, e, event_name)
```

- **type** 必填    
- e 选填，默认值为空   
- event_name 选填，默认值为空



# 位置与顺序

建议在函数的起始位置加入。

```js
function (e) {
  this.$tracking.click(e)
  //
  ...
}
```


